@@ -17,6 +17,8 @@
 
 from django import template
 
+from Zephyrus.blog_extension.models import ViewCount as ViewCountModel
+
 register = template.Library()
 
 # FIXME: 不知為何使用 {% allCategoryRoots categories %} 會在畫面上 render 出字來，
@@ -38,4 +40,24 @@ def allCategoryRoots(context, categories):
     context['roots'] = roots
     context['parents'] = parents
     return ''
+
+@register.simple_tag(takes_context=True)
+def viewCount(context, url=None):
+    request = context['request']
+    if url:
+        if not url.startswith('http'): 
+            url = request.build_absolute_uri('/')[:-1].strip("/") + url
+        
+        obj, created = ViewCountModel.objects.get_or_create(
+            url=url,
+        )
+    else:
+        url = request.build_absolute_uri(request.path)
+        obj, created = ViewCountModel.objects.get_or_create(
+            url=url,
+        )
+        obj.count += 1
+        obj.save()
+    
+    return obj.count
     
\ No newline at end of file
