@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: get_template.py 10597 2017-12-03 13:59:37Z Lavender $
+# $Id: get_template.py 10626 2017-12-10 09:05:41Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,11 +12,12 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-12-03 21:59:37 +0800 (週日, 03 十二月 2017) $
-# $Revision: 10597 $
+# $Date: 2017-12-10 17:05:41 +0800 (週日, 10 十二月 2017) $
+# $Revision: 10626 $
 
 import os
 import shutil
+import traceback
 
 from django.core.management.base import BaseCommand, CommandError
 
@@ -117,6 +118,8 @@ class Command(BaseCommand):
             logger.info('-----All OK!-----')
         except Exception as e:
             logger.error("get_template error:%s" % e)
+            with open('./AllError.log', 'w+') as log:
+                log.write(traceback.format_exc())
             raise
 
         
\ No newline at end of file
