@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: setup.py 11011 2018-05-06 04:26:57Z Lavender $
+# $Id: setup.py 11386 2019-03-13 08:54:27Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-05-06 12:26:57 +0800 (週日, 06 五月 2018) $
-# $Revision: 11011 $
+# $Date: 2019-03-13 17:54:27 +0900 (週三, 13 三月 2019) $
+# $Revision: 11386 $
 import os
 import sys
 import logging
@@ -123,7 +123,7 @@ def canAddPlugin(pkgName, pluginName):
     else:
         return True
                
-def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate, 
+def writeSettings(settingsPath, templateDir, staticDir, hasCmsTemplate, baseDir,
                   wizard=False, createProject=False):
     logger.info("-----Start write and backup settings.py-----")
     def getCMSTemplates():
@@ -186,8 +186,10 @@ else:
     
         if cms.__version__.startswith('3.5'):
             pluginList = []
+            requirementList = []
         else:
             pluginList = []
+            requirementList = []
         
         if createProject:
             if wizard:
@@ -207,15 +209,28 @@ else:
                     if canAddPlugin(
                         'djangocms-file', 'djangocms_file==2.0.2'):
                         pluginList.append('djangocms_file')
+                        requirementList.append('djangocms_file==2.0.2')
+                        
                     if canAddPlugin(
                         'djangocms-picture', 'djangocms_picture==2.0.6'):
                         pluginList.append('djangocms_picture')
+                        requirementList.append('djangocms_picture==2.0.6')
+                        
                 if canAddPlugin(
                     'djangocms-history', 'djangocms_history==0.5.3'):
                     pluginList.append('djangocms_history')
+                    requirementList.append('djangocms_history==0.5.3')
                 if canAddPlugin(
                     'djangocms-forms', 'djangocms_forms==0.2.5'):
                     pluginList.append('djangocms_forms')
+                    requirementList.append('djangocms_forms==0.2.5')
+                    
+            requirementList.append('djangocms_text_ckeditor==3.5.3')
+            
+            with open(os.path.join(baseDir, "requirements.txt"), 'a') as reqs:
+                reqs.write("\n")
+                for r in requirementList:
+                    reqs.write("%s\n" % r)
                    
         content += "INSTALLED_APPS += %s" % str(tuple(pluginList))
         content += CKEDITOR_SETTINGS
@@ -364,6 +379,14 @@ if __name__ == "__main__":
         except Exception as e:
             os.system("pip install cmsplugin-filer==1.1.3")
             import cms
+            
+    import djangocms_text_ckeditor
+    if not djangocms_text_ckeditor.__version__.startswith("3.5"):
+        try:
+            os.system("pip install -U djangocms_text_ckeditor==3.5.3")
+        except Exception as e:
+            logger.error("Can't install djangocms_text_ckeditor==3.5.3")
+            sys.exit(1)
        
     cmsVersion = cms.__version__.split('.')
    
@@ -431,7 +454,7 @@ if __name__ == "__main__":
         hasCmsTemplate = False
        
     writeSettings(settingsPath, 
-        templateDir, staticDir, hasCmsTemplate, 
+        templateDir, staticDir, hasCmsTemplate, baseDir,
         wizard=wizard, createProject=createProject)
        
     os.chdir(baseDir)
