@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 11155 2018-07-08 13:33:33Z Lavender $
+# $Id: forms.py 11237 2018-10-04 12:45:49Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,10 +12,11 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2018-07-08 22:33:33 +0900 (週日, 08 七月 2018) $
-# $Revision: 11155 $
+# $Date: 2018-10-04 21:45:49 +0900 (週四, 04 十月 2018) $
+# $Revision: 11237 $
 
 from django import forms
+from django.utils.translation import ugettext_lazy as _
 
 from Zephyrus.cms_oscar.models import OscarFeatured, OscarLatest
 from oscar.core.loading import get_model
@@ -29,9 +30,7 @@ if hasattr(Product, 'tags'):
 
     from taggit.models import Tag
 
-    tagList = [
-        (0, '------'),
-    ]
+    tagList = []
     try:
         for tag in Tag.objects.all():
             tagList.append((tag.id, tag.name))
@@ -40,16 +39,26 @@ if hasattr(Product, 'tags'):
 
 class OscarFeaturedForm(forms.ModelForm):
     if hasTags:
-        tag = forms.ChoiceField(
+        tag = forms.MultipleChoiceField(
             choices=tagList,
-            required=False
+            required=False,
+            help_text=_(
+                "If no choice. It will not filter product by tag.")
         )
 
+    def __init__(self, *args, **kwargs): 
+        super(OscarFeaturedForm, self) .__init__(*args, **kwargs) 
+        if hasTags:
+            if self.instance.tag:
+                self.fields['tag'].initial = self.instance.tag.split(",")
+            
+
     def save(self, commit=True):
         obj = super(OscarFeaturedForm, self).save(commit=commit)
 
-        if hasTags and not self.data['tag'] == 0:
-            obj.tag = self.data['tag']
+        if hasTags:
+            tags = ",".join(self.cleaned_data.get('tag', []))
+            obj.tag = tags
             obj.save()
 
         return obj
@@ -60,16 +69,25 @@ class OscarFeaturedForm(forms.ModelForm):
 
 class OscarLatestForm(forms.ModelForm):
     if hasTags:
-        tag = forms.ChoiceField(
+        tag = forms.MultipleChoiceField(
             choices=tagList,
-            required=False
+            required=False,
+            help_text=_(
+                "If no choice. It will not filter product by tag.")
         )
+    
+    def __init__(self, *args, **kwargs): 
+        super(OscarLatestForm, self) .__init__(*args, **kwargs) 
+        if hasTags:
+            if self.instance.tag:
+                self.fields['tag'].initial = self.instance.tag.split(",")
 
     def save(self, commit=True):
         obj = super(OscarLatestForm, self).save(commit=commit)
 
-        if hasTags and not self.data['tag'] == 0:
-            obj.tag = self.data['tag']
+        if hasTags:
+            tags = ",".join(self.cleaned_data.get('tag', []))
+            obj.tag = tags
             obj.save()
             
         return obj
