@@ -12,14 +12,14 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2017-04-23 12:33:47 +0800 (Sun, 23 Apr 2017) $
+# $Date: 2017-04-23 12:33:47 +0800 (週日, 23 四月 2017) $
 # $Revision: 9895 $ 
 
 from django.conf.urls import url
 
 from . import views
 
-app_name = 'landing'
+#app_name = 'landing'
 
 urlpatterns = [
     url(r'^email$', views.EmailView.as_view(), name='landing_email'),
